import type { RequestHandler } from '@sveltejs/kit';
import { Admin } from '$lib/server/database';
import { env as publicEnv } from '$env/dynamic/public';
import { env } from '$env/dynamic/private';
import { addSession, sessionCookieName } from '$lib/server/session';
import { Permissions } from '$lib/permissions';
import { LoginSchema } from './schema';

export const POST = (async ({ request, cookies }) => {
	const parseResult = await LoginSchema.safeParseAsync(await request.json());
	if (!parseResult.success) {
		return new Response(null, { status: 400 });
	}
	const data = parseResult.data;

	if (
		env.ADMIN_USER &&
		env.ADMIN_PASSWORD &&
		data.username == env.ADMIN_USER &&
		data.password == env.ADMIN_PASSWORD
	) {
		cookies.set(
			sessionCookieName,
			addSession({ id: -1, permissions: new Permissions(Permissions.allPermissions()) }),
			{
				path: `${publicEnv.PUBLIC_BASE_PATH}/admin`,
				maxAge: 60 * 60 * 24 * 90,
				httpOnly: true,
				secure: true
			}
		);
		return new Response();
	}

	const user = await Admin.findOne({ where: { username: data.username } });
	if (user && user.validatePassword(data.password)) {
		cookies.set(sessionCookieName, addSession(user), {
			path: `${publicEnv.PUBLIC_BASE_PATH}/admin`,
			maxAge: 60 * 60 * 24 * 90,
			httpOnly: true,
			secure: true
		});
		return new Response();
	} else {
		console.log(`failed login attempt for user ${data.username}`);
		return new Response(null, {
			status: 401
		});
	}
}) satisfies RequestHandler;
